0.1.6 - 2014-09-04
==================
* Use TracebackFuture to show correct stack traces when exceptions occur
* Add CHANGELOG.md

0.1.5 - 2014-08-28
==================
* Add a gen_test implementation

0.1.4 - 2014-08-28
==================
* Fix bug with nested groutines + double yield

0.1.3 - 2014-08-28
==================
* Add gcall to the API

0.1.2 - 2014-08-28
==================
* Short-circuit futures that have already completed

0.1.1 - 2014-08-28
==================
* Initial working version
